#####
Safir
#####

Safir is the SQuaRE Framework for Roundtable
============================================

Roundtable_ is the SQuaRE application and bot deployment platform, hosted on Kubernetes with Argo CD.
Safir is a Python package that lets you develop Roundtable bots, based on the `FastAPI`_ asyncio web framework.

Safir is developed on GitHub at https://github.com/lsst-sqre/safir.

Getting started
===============

.. toctree::
   :maxdepth: 1

   changelog

Tutorials
=========

.. toctree::
   :maxdepth: 1

   set-up-from-template

Guides
======

.. toctree::
   :maxdepth: 2

   arq
   database
   http-client
   gafaelfawr
   kubernetes
   logging
   x-forwarded
   ivoa

API
===

.. toctree::
   :maxdepth: 2

   api

Development guide
=================

.. toctree::
   :maxdepth: 1

   dev/development
   dev/release

Indices
=======

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. * :ref:`glossary`
